Contributing
------------

If you want to help make this project better you are officially an awesome
person.  Any and all contributions, whether it's patches, documentation, or
bug reports, are very much welcome and appreciated.

`Pull requests <https://github.com/DramaFever/calcifer/pulls>`_ or `Github issues <https://github.com/DramaFever/calcifer/issues>`_ are always welcome.  If you want to contribute a patch please do the following.

1. Fork this repo and create a new branch
2. Do work
3. Add tests for your work (Mandatory)
4. Submit a pull request
5. Wait for Coveralls and Travis-CI to run through your PR
6. It'll be code reviewed and merged

As a note, code without sufficient tests will not be merged.
